@@ -10,7 +10,7 @@
 #ifndef APPDEFINE_H
 #define APPDEFINE_H
 
-#include "appconfig.h"
+//#include "ghemicalconfig2.h"
 
 /*################################################################################################*/
 
