@@ -14,8 +14,8 @@
 
 #include "appdefine.h"
 
-//#include "time.h"	// for frames-per-second counter...
-//#include "sys/time.h"	// for frames-per-second counter...
+#include <GL/gl.h>
+#include <GL/glu.h>
 
 #include <strstream>
 using namespace std;
@@ -374,7 +374,7 @@ void camera::RenderWindow(graphics_view * gv, rmode rm, int x, int y)
 			//if (gv->GetProject()->select_buffer[tmp4[1] + 2] > tmp3)	// modified, highest z-value...
 			{
 				tmp2 = tmp4[1];
-				tmp3 = gv->GetProject()->select_buffer[tmp4[1] + 1];		// original, lowest z-value...
+				tmp3 = gv->GetProject()->select_buffer[tmp4[1] + 1];	// original, lowest z-value...
 				//tmp3 = gv->GetProject()->select_buffer[tmp4[1] + 2];	// modified, highest z-value...
 			}
 			
@@ -432,18 +432,21 @@ void camera::RenderWindow(graphics_view * gv, rmode rm, int x, int y)
 			}
 			else
 			{
+				const dummy_object * ref = NULL;
 				switch (name_vector[0])
 				{
 					case GLNAME_LIGHT:
-					gv->GetProject()->SelectLight((const dummy_object *) name_vector[1]);
+					ref = (const dummy_object *) prj->FindPtrByGLName(name_vector[1]);
+					gv->GetProject()->SelectLight(ref);
 					break;
 					
 					case GLNAME_OBJECT:
-					gv->GetProject()->SelectObject((const dummy_object *) name_vector[1]);
+					ref = (const dummy_object *) prj->FindPtrByGLName(name_vector[1]);
+					gv->GetProject()->SelectObject(ref);
 					break;
-				} // switch
-			} // test
-		} // select
+				}
+			}
+		}
 	}
 }
 
