@@ -10,11 +10,12 @@
 #include "project.h"
 
 #include <ghemical/engine.h>
+
 #include <ghemical/eng1_qm.h>
 #include <ghemical/eng1_mm.h>
 #include <ghemical/eng1_sf.h>
+
 #include <ghemical/eng2_qm_mm.h>
-#include <ghemical/eng2_mm_sf.h>
 
 #include <iomanip>
 #include <strstream>
@@ -465,8 +466,8 @@ if (n1 >= ar_vector.size()) { cout << "ERROR : invalid atom id number!!!" << end
 	if (!prj.current_setup && !strcmp(setup1_qm::static_GetClassName(), su_cn)) prj.current_setup = new setup1_qm(& prj);
 	if (!prj.current_setup && !strcmp(setup1_mm::static_GetClassName(), su_cn)) prj.current_setup = new setup1_mm(& prj);
 	if (!prj.current_setup && !strcmp(setup1_sf::static_GetClassName(), su_cn)) prj.current_setup = new setup1_sf(& prj, false);
+	
 	if (!prj.current_setup && !strcmp(setup2_qm_mm::static_GetClassName(), su_cn)) prj.current_setup = new setup2_qm_mm(& prj);
-	if (!prj.current_setup && !strcmp(setup2_mm_sf::static_GetClassName(), su_cn)) prj.current_setup = new setup2_mm_sf(& prj, false);
 	
 	if (!prj.current_setup)
 	{
@@ -755,9 +756,9 @@ if (n1 >= ar_vector.size()) { cout << "ERROR : invalid atom id number!!!" << end
 	
 	if (!prj.current_setup && !strcmp(setup1_qm::static_GetClassName(), su_cn)) prj.current_setup = new setup1_qm(& prj);
 	if (!prj.current_setup && !strcmp(setup1_mm::static_GetClassName(), su_cn)) prj.current_setup = new setup1_mm(& prj);
-	if (!prj.current_setup && !strcmp(setup1_sf::static_GetClassName(), su_cn)) prj.current_setup = new setup1_sf(& prj, false);
+	if (!prj.current_setup && !strcmp(setup1_sf::static_GetClassName(), su_cn)) prj.current_setup = new setup1_sf(& prj, false)
+	;
 	if (!prj.current_setup && !strcmp(setup2_qm_mm::static_GetClassName(), su_cn)) prj.current_setup = new setup2_qm_mm(& prj);
-	if (!prj.current_setup && !strcmp(setup2_mm_sf::static_GetClassName(), su_cn)) prj.current_setup = new setup2_mm_sf(& prj, false);
 	
 	if (!prj.current_setup)
 	{
@@ -915,7 +916,10 @@ void WriteGPR_v100(project & prj, ostream & file)
 
 void WriteGPR(project & prj, ostream & file)
 {
-prj.Message("PLEASE NOTE : This file format is experimental!\nIt is safer to use the stable v1.0 of this program.");
+prj.Message("\
+PLEASE NOTE : This file format is EXPERIMENTAL!\n\n\
+This file format is NOT compatible with OpenBabel-1.100.2.\n\
+Please use the File/Export to generate OpenBabel-compatible files.");
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 	if (my_num_locale != NULL) cout << "WARNING : my_num_locale != NULL" << endl;	// todo : change into a thread-safe lock???
 	// store the current (numeric) locale into my_num_locale, and switch into "C" numeric locale...
