@@ -7,11 +7,11 @@
 
 /*################################################################################################*/
 
-#include "appconfig.h"
-
 #ifndef MOLDYN_DIALOG_H
 #define MOLDYN_DIALOG_H
 
+//#include "ghemicalconfig2.h"
+
 #include "glade_dialog.h"
 
 #include <ghemical/moldyn.h>
