@@ -10,7 +10,7 @@
 #ifndef GLADE_DIALOG_H
 #define GLADE_DIALOG_H
 
-#include "appconfig.h"
+//#include "ghemicalconfig2.h"
 
 #include <glade/glade.h>
 
