@@ -10,7 +10,9 @@
 #include "gtk_graphics_view.h"
 
 #include <ghemical/utility.h>
-#include <ghemical/libconfig.h>		// ENABLE_OPENBABEL
+#include <ghemical/libghemicalconfig2.h>	// ENABLE_OPENBABEL
+
+#include <GL/gl.h>
 
 /*################################################################################################*/
 
@@ -66,6 +68,7 @@ GtkActionEntry gtk_graphics_view::entries[] =
 	{ "RendViewsCreateCam", NULL, "New Camera", NULL, "Create a new view with a new camera", (GCallback) gtk_graphics_view::popup_ViewsNewCam },
 	{ "RendViewsCreateView", NULL, "New View", NULL, "Create a new view using the current camera", (GCallback) gtk_graphics_view::popup_ViewsNewView },
 	{ "RendViewsCreateELD", NULL, "Energy-level Diagram", NULL, "Create a new energy-level diagram view", (GCallback) gtk_project::popup_ViewsNewELD },
+	{ "RendViewsCreateSSC", NULL, "Secondary Structure Constraints", NULL, "Create a new secondary structure constraints view", (GCallback) gtk_project::popup_ViewsNewSSC },
 	
 	{ "RendLightsMenu", NULL, "_Lights" },
 	// ^^^^^^^^^^^^^^
@@ -216,6 +219,7 @@ const char * gtk_graphics_view::ui_description =
 "          <menuitem action='RendViewsCreateView'/>"
 "          <separator/>"
 "          <menuitem action='RendViewsCreateELD'/>"
+"          <menuitem action='RendViewsCreateSSC'/>"
 "        </menu>"
 "        <menuitem action='RendViewsDeleteView'/>"
 "        <separator/>"
