@@ -480,6 +480,16 @@ void gtk_project::popup_ViewsNewELD(GtkWidget *, gpointer data)
 	}
 }
 
+void gtk_project::popup_ViewsNewSSC(GtkWidget *, gpointer data)
+{
+	gtk_graphics_view * gv = gtk_graphics_view::GetGV((GtkWidget *) data);
+	gtk_project * prj = dynamic_cast<gtk_project *>(gv->prj);
+	if (prj)
+	{
+		prj->AddSecondaryStructureConstraintsView(true);
+	}
+}
+
 void gtk_project::popup_RModeBallStick(GtkWidget *, gpointer data)
 {
 	gtk_graphics_view * gv = gtk_graphics_view::GetGV((GtkWidget *) data);
