@@ -565,6 +565,31 @@ eld_view * gtk_class_factory::ProduceELDView(project * mdl, bool detach)
 	return eldv;
 }
 
+ssc_view * gtk_class_factory::ProduceSSCView(project * mdl, bool detach)
+{
+	gtk_project * prj2 = dynamic_cast<gtk_project *>(mdl);
+	gtk_ssc_view * sscv = new gtk_ssc_view(prj2);
+	
+	if (detach)
+	{
+		sscv->detached = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+		gtk_window_set_default_size(GTK_WINDOW(sscv->detached), 400, 400);
+		
+		gtk_container_add(GTK_CONTAINER(sscv->detached), sscv->view_widget);
+		gtk_signal_connect(GTK_OBJECT(sscv->detached), "delete_event", GTK_SIGNAL_FUNC(gtk_rcp_view::DetachedDeleteHandler), NULL);
+		
+		gtk_widget_show(sscv->detached);
+	}
+	else
+	{
+		gtk_notebook_append_page(GTK_NOTEBOOK(prj2->notebook_widget), sscv->view_widget, sscv->label_widget);
+		gtk_notebook_set_page(GTK_NOTEBOOK(prj2->notebook_widget), -1);		// activate the last page.
+	}
+	
+	gtk_widget_show(GTK_WIDGET(prj2->notebook_widget));
+	return sscv;
+}
+
 /*################################################################################################*/
 
 // eof
