@@ -227,7 +227,7 @@ gtk_app::gtk_app(void)
 	g_signal_connect(G_OBJECT(main_window), "delete_event", G_CALLBACK(gtk_app::DeleteEventHandler), NULL);
 	g_signal_connect(G_OBJECT(main_window), "destroy", G_CALLBACK(gtk_app::DestroyHandler), NULL);
 	
-	main_vbox = gtk_vbox_new(FALSE, 1);
+	main_vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(main_vbox), 1);
 	gtk_container_add(GTK_CONTAINER(main_window), main_vbox);
 	
@@ -252,10 +252,10 @@ gtk_app::gtk_app(void)
 	}
 	
 	main_menubar = gtk_ui_manager_get_widget(ui_manager, "/MainMenu");
-	gtk_container_add(GTK_CONTAINER(main_vbox), main_menubar);
-
+	gtk_box_pack_start(GTK_BOX(main_vbox), main_menubar, FALSE, FALSE, 0);
+	
 	main_toolbar = gtk_ui_manager_get_widget(ui_manager, "/MainTB");
-	gtk_container_add(GTK_CONTAINER(main_vbox), main_toolbar);
+	gtk_box_pack_start(GTK_BOX(main_vbox), main_toolbar, FALSE, FALSE, 0);
 	
 mtb_mtool_draw = gtk_ui_manager_get_widget(ui_manager, "/MainTB/MainTools/dr");
 mtb_mtool_erase = gtk_ui_manager_get_widget(ui_manager, "/MainTB/MainTools/er");
@@ -704,9 +704,26 @@ static BonoboObject * control_factory(BonoboGenericFactory *, const char * objec
 // the main function.
 // ^^^^^^^^^^^^^^^^^^
 
+static gchar * opt_f = NULL;
+static gchar * opt_i = NULL;
+
+static GOptionEntry option_entries[] =
+{
+	{ "file=filename", 'f', 0, G_OPTION_ARG_STRING, & opt_f, "open a file", NULL },
+	{ "import=filename", 'i', 0, G_OPTION_ARG_STRING, & opt_i, "import a file", NULL },
+	{ NULL }
+};
+
 int main(int argc, char ** argv)
 {
-	bool bonobo_server_flag = false;
+	GError * error = NULL;
+	
+	GOptionContext * option_context = g_option_context_new("- a GTK2 molecular modelling program");
+	g_option_context_add_main_entries(option_context, option_entries, NULL);
+	g_option_context_add_group(option_context, gtk_get_option_group(TRUE));
+	g_option_context_parse(option_context, & argc, & argv, & error);
+	
+	bool bonobo_server_flag = false;	// TODO ; handle this above as well?
 	for (int arg = 1;arg < argc;arg++)
 	{
 		if (!strcmp(argv[arg], "--bonobo-server")) bonobo_server_flag = true;
@@ -753,6 +770,36 @@ int main(int argc, char ** argv)
 		singleton_cleaner<gtk_app> app_cleaner;
 		app_cleaner.SetInstance(gtk_app::GetInstance());
 		
+		if (opt_f != NULL)
+		{
+			ifstream ifile;
+			ifile.open(opt_f, ios::in);
+			ReadGPR(* gtk_app::GetPrj(), ifile, false);
+			ifile.close();
+			
+			//char buffer[256];
+			//prj->ParseProjectFileNameAndPath(filename);
+			//prj->GetProjectFileName(buffer, 256, true);
+		}
+		else if (opt_i != NULL)
+		{
+			
+#ifdef ENABLE_OPENBABEL
+			
+			gtk_app::GetPrj()->ImportFile(opt_i, 0);
+			
+			//gtk_app::GetPrj()->ParseProjectFileNameAndPath(filename);
+			
+#else	// ENABLE_OPENBABEL
+			
+			cout << "sorry! file import feature is disabled ; you need to recompile" << endl;
+			cout << "libghemical with --enable-openbabel option in order to fix this." << endl;
+			exit(EXIT_FAILURE);
+			
+#endif	// ENABLE_OPENBABEL
+			
+		}
+		
 		gtk_main();
 		
 #ifdef ENABLE_THREADS
