@@ -22,7 +22,8 @@ color_surface::color_surface(cs_param & p1)
 {
 	prj = p1.prj;
 	data = p1.data;
-	name = p1.name;
+	
+	my_glname = p1.my_glname;
 	
 	transparent = p1.transparent;
 	automatic_cv2 = p1.automatic_cv2;
@@ -357,7 +358,7 @@ void color_surface::Update(void)
 void color_surface::Render(void)
 {
 	glPushName(GLNAME_OBJECT);
-	glPushName((iGLu) name);
+	glPushName(my_glname);
 	
 	if (wireframe)
 	{
@@ -534,7 +535,7 @@ color_surface_object::color_surface_object(const object_location & p1, cs_param
 	while (true)
 	{
 		param->data = GetLocData();
-		param->name = (const dummy_object *) this;
+		param->my_glname = p2.prj->RegisterGLName((dummy_object *) this);
 		
 		cs_vector.push_back(new color_surface(* param));
 		
