@@ -22,6 +22,10 @@
 
 #include "appdefine.h"
 
+#include <GL/gl.h>
+#include <GL/glu.h>
+#include <GL/glut.h>
+
 #include <strstream>
 #include <algorithm>
 using namespace std;
@@ -675,149 +679,6 @@ void plot2d_view::ImportData(plot2d_view * p)
 
 /*################################################################################################*/
 
-rcp_view::rcp_view(project * p1, i32s p2, const char * s1, const char * sv) : plot1d_view(p1, p2, s1, sv)
-{
-	ready = false;
-	
-	r_treshold = 0.65;	// default for range 0<->1...
-	p_treshold = 0.35;	// default for range 0<->1...
-}
-
-rcp_view::~rcp_view(void)
-{
-}
-
-void rcp_view::SortDataAndCalcRC(void)
-{
-	sort(dv.begin(), dv.end());
-	
-	i32s index = 0; fGL ets = dv.front().v;
-	for (i32s n1 = 1;n1 < (i32s) dv.size();n1++)
-	{
-		if (dv[n1].v > ets)
-		{
-			index = n1;
-			ets = dv[n1].v;
-		}
-	}
-	
-	// first calculate the final reaction coordinates...
-	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
-	
-	fGL * c_ts = (fGL *) (((char *) dv[index].udata) + sizeof(i32s));
-	
-fGL minrc = 0.0;
-fGL maxrc = 0.0;
-	for (i32u n1 = 0;n1 < dv.size();n1++)
-	{
-		if (n1 == (i32u) index)
-		{
-			dv[n1].c1 = 0.0;
-			continue;
-		}
-		
-		fGL * c_xx = (fGL *) (((char *) dv[n1].udata) + sizeof(i32s));
-		
-		fGL rc = 0.0;
-		for (i32u n5 = 0;n5 < patoms.size();n5++)
-		{
-			const fGL * crd1 = & c_ts[patoms[n5] * 3];
-			const fGL * crd2 = & c_xx[patoms[n5] * 3];
-			
-			for (i32u n6 = 0;n6 < 3;n6++)
-			{
-				fGL tmp1 = crd2[n6] - crd1[n6];
-				rc += tmp1 * tmp1;
-			}
-		}
-		
-		rc = sqrt(rc);
-		if (n1 < (i32u) index) rc = -rc;
-		
-if (rc < minrc) minrc = rc;
-if (rc > maxrc) maxrc = rc;
-		dv[n1].c1 = rc;
-	}
-	
-// what the heck?!?!?! plot1d_view is unable to display negative values???
-// then, just re-scale them form 0 to 1. THIS IS A BIT STRANGE...
-
-	for (i32u n1 = 0;n1 < dv.size();n1++)
-	{
-		//fGL rc = ((fGL) n1) / ((fGL) dv.size());		// debug ; just use the sort order...
-		fGL rc = (dv[n1].c1 - minrc) / (maxrc - minrc);		// calculate RC using the distances...
-		
-		dv[n1].c1 = rc;
-	}
-	
-	// ...and then update the display tresholds.
-	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
-	
-	const f64 eri = dv.front().v;
-	const f64 epi = dv.back().v;
-	
-	f64 limit_r = (epi + ets) / 2.0;
-	for (i32s n1 = index;n1 < (i32s) dv.size();n1++)
-	{
-		if (dv[n1].v < limit_r)
-		{
-			r_treshold = (dv[n1].c1 + dv[n1 - 1].c1) / 2.0;
-			break;
-		}
-	}
-	
-	f64 limit_p = (eri + ets) / 2.0;
-	for (i32s n1 = index;n1 >= 0;n1--)
-	{
-		if (dv[n1].v < limit_p)
-		{
-			p_treshold = (dv[n1].c1 + dv[n1 + 1].c1) / 2.0;
-			break;
-		}
-	}
-	
-	char txtbuff[256]; ostrstream txts(txtbuff, sizeof(txtbuff));
-	txts << "the tresholds were set to " << r_treshold << " and " << p_treshold << endl << ends;
-	mdl->PrintToLog(txtbuff);
-	
-	ready = true;
-}
-
-void rcp_view::UserEvent(i32s x, i32s y)
-{
-	if (!ready) return;
-	
-	// first setup the bonds...
-	// ^^^^^^^^^^^^^^^^^^^^^^^^
-	
-	if (!(size[0] > 1)) return;
-	fGL sx = 1.2 * (fGL) x / (fGL) size[0] - 0.1;
-	
-	if (sx < 0.0) return;
-	if (sx > 1.0) return;
-	
-	fGL s1 = sx * (max1 - min1);
-	
-	bool show_r_bonds = (s1 < r_treshold);
-	for (i32u n1 = 0;n1 < rbonds.size();n1++)
-	{
-		rbonds[n1]->do_not_render_TSS_fixmelater = !show_r_bonds;
-	}
-	
-	bool show_p_bonds = (s1 > p_treshold);
-	for (i32u n1 = 0;n1 < pbonds.size();n1++)
-	{
-		pbonds[n1]->do_not_render_TSS_fixmelater = !show_p_bonds;
-	}
-	
-	// ...and finally call base class UserEvent().
-	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
-	
-	plot1d_view::UserEvent(x, y);
-}
-
-/*################################################################################################*/
-
 eld_view::eld_view(project * p1) : plotting_view(p1)
 {
 	mdl = p1;
@@ -860,6 +721,9 @@ void eld_view::Render(void)
 	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 	
 	// set projection and call gluLookAt() to set up our "eye".
+	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+	// the principle here is that we set up the "eye" in a fixed way
+	// and then ask different (orthogonal) projections (depending on Y-zoom).
 	
 // PREFS: making this value bigger will make the left margin (for displaying text) bigger.
 	fGL diagram_left_margin = 0.2 + 0.5;
@@ -1050,4 +914,223 @@ void eld_view::UserEvent(i32s, i32s)
 
 /*################################################################################################*/
 
+rcp_view::rcp_view(project * p1, i32s p2, const char * s1, const char * sv) : plot1d_view(p1, p2, s1, sv)
+{
+	ready = false;
+	
+	r_treshold = 0.65;	// default for range 0<->1...
+	p_treshold = 0.35;	// default for range 0<->1...
+}
+
+rcp_view::~rcp_view(void)
+{
+}
+
+void rcp_view::SortDataAndCalcRC(void)
+{
+	sort(dv.begin(), dv.end());
+	
+	i32s index = 0; fGL ets = dv.front().v;
+	for (i32s n1 = 1;n1 < (i32s) dv.size();n1++)
+	{
+		if (dv[n1].v > ets)
+		{
+			index = n1;
+			ets = dv[n1].v;
+		}
+	}
+	
+	// first calculate the final reaction coordinates...
+	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+	
+	fGL * c_ts = (fGL *) (((char *) dv[index].udata) + sizeof(i32s));
+	
+fGL minrc = 0.0;
+fGL maxrc = 0.0;
+	for (i32u n1 = 0;n1 < dv.size();n1++)
+	{
+		if (n1 == (i32u) index)
+		{
+			dv[n1].c1 = 0.0;
+			continue;
+		}
+		
+		fGL * c_xx = (fGL *) (((char *) dv[n1].udata) + sizeof(i32s));
+		
+		fGL rc = 0.0;
+		for (i32u n5 = 0;n5 < patoms.size();n5++)
+		{
+			const fGL * crd1 = & c_ts[patoms[n5] * 3];
+			const fGL * crd2 = & c_xx[patoms[n5] * 3];
+			
+			for (i32u n6 = 0;n6 < 3;n6++)
+			{
+				fGL tmp1 = crd2[n6] - crd1[n6];
+				rc += tmp1 * tmp1;
+			}
+		}
+		
+		rc = sqrt(rc);
+		if (n1 < (i32u) index) rc = -rc;
+		
+if (rc < minrc) minrc = rc;
+if (rc > maxrc) maxrc = rc;
+		dv[n1].c1 = rc;
+	}
+	
+// what the heck?!?!?! plot1d_view is unable to display negative values???
+// then, just re-scale them form 0 to 1. THIS IS A BIT STRANGE...
+
+	for (i32u n1 = 0;n1 < dv.size();n1++)
+	{
+		//fGL rc = ((fGL) n1) / ((fGL) dv.size());		// debug ; just use the sort order...
+		fGL rc = (dv[n1].c1 - minrc) / (maxrc - minrc);		// calculate RC using the distances...
+		
+		dv[n1].c1 = rc;
+	}
+	
+	// ...and then update the display tresholds.
+	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+	
+	const f64 eri = dv.front().v;
+	const f64 epi = dv.back().v;
+	
+	f64 limit_r = (epi + ets) / 2.0;
+	for (i32s n1 = index;n1 < (i32s) dv.size();n1++)
+	{
+		if (dv[n1].v < limit_r)
+		{
+			r_treshold = (dv[n1].c1 + dv[n1 - 1].c1) / 2.0;
+			break;
+		}
+	}
+	
+	f64 limit_p = (eri + ets) / 2.0;
+	for (i32s n1 = index;n1 >= 0;n1--)
+	{
+		if (dv[n1].v < limit_p)
+		{
+			p_treshold = (dv[n1].c1 + dv[n1 + 1].c1) / 2.0;
+			break;
+		}
+	}
+	
+	char txtbuff[256]; ostrstream txts(txtbuff, sizeof(txtbuff));
+	txts << "the tresholds were set to " << r_treshold << " and " << p_treshold << endl << ends;
+	mdl->PrintToLog(txtbuff);
+	
+	ready = true;
+}
+
+void rcp_view::UserEvent(i32s x, i32s y)
+{
+	if (!ready) return;
+	
+	// first setup the bonds...
+	// ^^^^^^^^^^^^^^^^^^^^^^^^
+	
+	if (!(size[0] > 1)) return;
+	fGL sx = 1.2 * (fGL) x / (fGL) size[0] - 0.1;
+	
+	if (sx < 0.0) return;
+	if (sx > 1.0) return;
+	
+	fGL s1 = sx * (max1 - min1);
+	
+	bool show_r_bonds = (s1 < r_treshold);
+	for (i32u n1 = 0;n1 < rbonds.size();n1++)
+	{
+		rbonds[n1]->do_not_render_TSS_fixmelater = !show_r_bonds;
+	}
+	
+	bool show_p_bonds = (s1 > p_treshold);
+	for (i32u n1 = 0;n1 < pbonds.size();n1++)
+	{
+		pbonds[n1]->do_not_render_TSS_fixmelater = !show_p_bonds;
+	}
+	
+	// ...and finally call base class UserEvent().
+	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+	
+	plot1d_view::UserEvent(x, y);
+}
+
+/*################################################################################################*/
+
+ssc_view::ssc_view(project * p1) : plotting_view(p1)
+{
+	mdl = p1;
+	
+	pos_x = 0.0;
+	pos_y = 0.0;
+}
+
+ssc_view::~ssc_view(void)
+{
+}
+
+void ssc_view::Render(void)
+{
+	if (size[0] < 0) return;			// skip rendering if invalid window!!!
+	
+	glMatrixMode(GL_PROJECTION);
+	glLoadIdentity();
+	
+	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+	
+	// set projection and call gluLookAt() to set up our "eye".
+	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+	// the principle here is that we ask a fixed (orthogonal) projection,
+	// and then move our "eye" so that we can see different parts of the view,
+	// if needed (X- and Y-translations).
+	
+	fGL diagram_left_margin = 0.2 + 0.5;
+	
+	i32s width = size[0]; i32s height = size[1]; glViewport(0, 0, width, height);
+	glOrtho(0.0, width, 0.0, height, -0.5, +1.5);
+	// left,right,bottom,top,near,far
+	glMatrixMode(GL_MODELVIEW); glLoadIdentity();
+	
+	gluLookAt(0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0);		// pos_x??? pos_y???
+	// eyex,eyey,eyez,cenx,ceny,cenz,upx,upy,upz
+	
+// render...
+// render...
+// render...
+
+	if (!mdl->ref_civ)
+	{
+		return;
+	}
+	
+	vector<chn_info> & ci_vector = (* mdl->ref_civ);
+// make a COMMON framework for SSC (now at SF)!
+// make a COMMON framework for SSC (now at SF)!
+// make a COMMON framework for SSC (now at SF)!
+	
+	// ribbon.cpp
+	
+}
+
+void ssc_view::ZoomEvent(i32s dy)	// pois
+{
+}
+
+void ssc_view::TransEvent(i32s dy)	// dx, dy???
+{
+	//center -= 0.5 * scale * (fGL) dy / (fGL) size[1];
+	Update();
+}
+
+// figure out the selections using coordinates instead of OpenGL selection mode?!?!?! might be simpler in this 2-dimensional case...
+// figure out the selections using coordinates instead of OpenGL selection mode?!?!?! might be simpler in this 2-dimensional case...
+// figure out the selections using coordinates instead of OpenGL selection mode?!?!?! might be simpler in this 2-dimensional case...
+
+void ssc_view::UserEvent(i32s, i32s)
+{
+	cout << "UserEvent() was called!" << endl;
+}
+
+/*################################################################################################*/
+
 // eof
